@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::AuthorsFromGit;
 # ABSTRACT: Add per-file per-year copyright info to each Perl document
-$Dist::Zilla::Plugin::AuthorsFromGit::VERSION = '0.002';
+$Dist::Zilla::Plugin::AuthorsFromGit::VERSION = '0.003';
 use Git::Wrapper;
 use DateTime;
 use List::MoreUtils qw(uniq sort_by);
@@ -19,7 +19,7 @@ use namespace::autoclean;
 sub gitauthorlist {
   my ($file, $git)= @_;
 
-  my @log_lines = $git->RUN('log', '--format=%H %at %aN', '--', $file->name);
+  my @log_lines = $git->RUN('log', '--follow', '--format=%H %at %aN', '--', $file->name);
   my @outputlines;
   push @outputlines, "";
 
@@ -155,7 +155,7 @@ Dist::Zilla::Plugin::AuthorsFromGit - Add per-file per-year copyright info to ea
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
